import request from '@/plugin/axios'

//查询列表
export function getPageList(data) {
    return request({
        url:'/electric/getElectricInfoByPage',
        method:'post',
        data
    })
}

//新增和修改
export function saveOrUpdataList(data) {
    return request({
        url: '/electric/saveOrUpdataElectricInfo',
        method: 'post',
        data
    })
}

//删除
export function deleteList(data) {
    return request({
        url:'/electric/delElectricInfo',
        method:'post',
        data
    })
}

//编辑回显
export function getList(data) {
    return request({
        url:'/electric/getElectricInfoUpdata',
        method:'post',
        data
    })
}

//购电回显
export function getrecordList(data) {
    return request({
        url:'/electric/getElectricInfoUpdata',
        method:'post',
        data
    })
}

//购电
export function saveList(data) {
    return request({
        url:'/electric/saveElectricBuyRecord',
        method: 'post',
        data
    })
}

